DirectSelectItem<T> class

Widget that defines direct select list appearance Usage Example

DirectSelectItem

Inheritance

Constructors

DirectSelectItem({Key? key, dynamic scaleFactor = 4.0, required T value, required Widget itemBuilder(BuildContext context, T value), double itemHeight = 48.0, dynamic isSelected = false})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isSelected → dynamic
Defines is this item is selected
final
itemBuilder → Widget Function(BuildContext context, T value)
Item builder
final
itemHeight → double
Height of items in list
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
opacity → ValueNotifier<double>
Opacity unselected item
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → ValueNotifier<double>
Initial item scale
final
scaleFactor → dynamic
the more value the MORE max scale DECREASES
final
value → T
Value of item
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getSelectedItem(GlobalKey<DirectSelectItemState> animatedStateKey, dynamic paddingGlobalKey) → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
updateOpacity(double opacity) → void
updateScale(double scale) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited