DirectSelectList<T> class

Widget that contains items and responds to user's interaction Usage Example

final dsl2 = DirectSelectList<String>(
   values: _numbers,
   itemBuilder: (String value) => getDropDownMenuItem(value),
   focusedItemDecoration: _getDslDecoration());
Inheritance

Constructors

DirectSelectList({Key? key, required List<T> values, required DirectSelectItemsBuilder<T> itemBuilder, dynamic onItemSelectedListener(T value, int selectedIndex, BuildContext context)?, Decoration? focusedItemDecoration, int defaultItemIndex = 0, VoidCallback? onUserTappedListener})

Properties

defaultItemIndex → int
Default selected item index
final
focusedItemDecoration → Decoration?
Current focused item overlay
final
hashCode → int
The hash code for this object.
no setterinherited
items → List<DirectSelectItem<T>>
Item widgets
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onItemSelectedListener → dynamic Function(T value, int selectedIndex, BuildContext context)?
Function to execute when item selected
final
onUserTappedListener → VoidCallback?
Callback for action when user just tapped instead of hold and scroll
final
paddingItemController → PaddingItemController
Holds GlobalKey for RectGetter
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedItem → ValueNotifier<int>
Notifies state about new item selected
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getSelectedItem() → T
getSelectedItemIndex() → int
itemHeight() → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setSelectedItemIndex(int index) → void
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited